Struct google_tagmanager1::api::Account[][src]

pub struct Account {
    pub account_id: Option<String>,
    pub fingerprint: Option<String>,
    pub name: Option<String>,
    pub share_data: Option<bool>,
}

Represents a Google Tag Manager Account.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

account_id: Option<String>

The Account ID uniquely identifies the GTM Account.

fingerprint: Option<String>

The fingerprint of the GTM Account as computed at storage time. This value is recomputed whenever the account is modified.

name: Option<String>

Account display name. @mutable tagmanager.accounts.create @mutable tagmanager.accounts.update

share_data: Option<bool>

Whether the account shares data anonymously with Google and others. @mutable tagmanager.accounts.create @mutable tagmanager.accounts.update