pub struct Container {
pub account_id: Option<String>,
pub container_id: Option<String>,
pub domain_name: Option<Vec<String>>,
pub enabled_built_in_variable: Option<Vec<String>>,
pub fingerprint: Option<String>,
pub name: Option<String>,
pub notes: Option<String>,
pub public_id: Option<String>,
pub time_zone_country_id: Option<String>,
pub time_zone_id: Option<String>,
pub usage_context: Option<Vec<String>>,
}Expand description
Represents a Google Tag Manager Container.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- containers create accounts (request|response)
- containers get accounts (response)
- containers update accounts (request|response)
Fields
account_id: Option<String>GTM Account ID.
container_id: Option<String>The Container ID uniquely identifies the GTM Container.
domain_name: Option<Vec<String>>Optional list of domain names associated with the Container.
enabled_built_in_variable: Option<Vec<String>>List of enabled built-in variables. Valid values include: pageUrl, pageHostname, pagePath, referrer, event, clickElement, clickClasses, clickId, clickTarget, clickUrl, clickText, formElement, formClasses, formId, formTarget, formUrl, formText, errorMessage, errorUrl, errorLine, newHistoryFragment, oldHistoryFragment, newHistoryState, oldHistoryState, historySource, containerVersion, debugMode, randomNumber, containerId.
fingerprint: Option<String>The fingerprint of the GTM Container as computed at storage time. This value is recomputed whenever the account is modified.
name: Option<String>Container display name.
notes: Option<String>Container Notes.
public_id: Option<String>Container Public ID.
time_zone_country_id: Option<String>Container Country ID.
time_zone_id: Option<String>Container Time Zone ID.
usage_context: Option<Vec<String>>List of Usage Contexts for the Container. Valid values include: web, android, ios.