pub struct Tag {Show 19 fields
pub account_id: Option<String>,
pub blocking_trigger_id: Option<Vec<String>>,
pub container_id: Option<String>,
pub fingerprint: Option<String>,
pub firing_trigger_id: Option<Vec<String>>,
pub live_only: Option<bool>,
pub name: Option<String>,
pub notes: Option<String>,
pub parameter: Option<Vec<Parameter>>,
pub parent_folder_id: Option<String>,
pub paused: Option<bool>,
pub priority: Option<Parameter>,
pub schedule_end_ms: Option<i64>,
pub schedule_start_ms: Option<i64>,
pub setup_tag: Option<Vec<SetupTag>>,
pub tag_firing_option: Option<String>,
pub tag_id: Option<String>,
pub teardown_tag: Option<Vec<TeardownTag>>,
pub type_: Option<String>,
}Expand description
Represents a Google Tag Manager Tag.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- containers tags create accounts (request|response)
- containers tags get accounts (response)
- containers tags update accounts (request|response)
Fields
account_id: Option<String>GTM Account ID.
blocking_trigger_id: Option<Vec<String>>Blocking trigger IDs. If any of the listed triggers evaluate to true, the tag will not fire.
container_id: Option<String>GTM Container ID.
fingerprint: Option<String>The fingerprint of the GTM Tag as computed at storage time. This value is recomputed whenever the tag is modified.
firing_trigger_id: Option<Vec<String>>Firing trigger IDs. A tag will fire when any of the listed triggers are true and all of its blockingTriggerIds (if any specified) are false.
live_only: Option<bool>If set to true, this tag will only fire in the live environment (e.g. not in preview or debug mode).
name: Option<String>Tag display name.
notes: Option<String>User notes on how to apply this tag in the container.
parameter: Option<Vec<Parameter>>The tag’s parameters.
parent_folder_id: Option<String>Parent folder id.
paused: Option<bool>True if the tag is paused.
priority: Option<Parameter>User defined numeric priority of the tag. Tags are fired asynchronously in order of priority. Tags with higher numeric value fire first. A tag’s priority can be a positive or negative value. The default value is 0.
schedule_end_ms: Option<i64>The end timestamp in milliseconds to schedule a tag.
schedule_start_ms: Option<i64>The start timestamp in milliseconds to schedule a tag.
setup_tag: Option<Vec<SetupTag>>The list of setup tags. Currently we only allow one.
tag_firing_option: Option<String>Option to fire this tag.
tag_id: Option<String>The Tag ID uniquely identifies the GTM Tag.
teardown_tag: Option<Vec<TeardownTag>>The list of teardown tags. Currently we only allow one.
type_: Option<String>GTM Tag Type.