Struct google_tagmanager1::api::UserAccess [−][src]
Represents a user’s permissions to an account and its container.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- permissions create accounts (request|response)
- permissions get accounts (response)
- permissions update accounts (request|response)
Fields
account_access: Option<AccountAccess>GTM Account access permissions. @mutable tagmanager.accounts.permissions.create @mutable tagmanager.accounts.permissions.update
account_id: Option<String>GTM Account ID.
container_access: Option<Vec<ContainerAccess>>GTM Container access permissions. @mutable tagmanager.accounts.permissions.create @mutable tagmanager.accounts.permissions.update
email_address: Option<String>User’s email address. @mutable tagmanager.accounts.permissions.create
permission_id: Option<String>Account Permission ID.