Struct google_tagmanager1::Rule
[−]
[src]
pub struct Rule {
pub container_id: Option<String>,
pub name: Option<String>,
pub rule_id: Option<String>,
pub notes: Option<String>,
pub fingerprint: Option<String>,
pub condition: Option<Vec<Condition>>,
pub account_id: Option<String>,
}Represents a Google Tag Manager Rule.
This type is not used in any activity, and only used as part of another schema.
Fields
container_id: Option<String>
GTM Container ID.
name: Option<String>
Rule display name.
rule_id: Option<String>
The Rule ID uniquely identifies the GTM Rule.
notes: Option<String>
User notes on how to apply this rule in the container.
fingerprint: Option<String>
The fingerprint of the GTM Rule as computed at storage time. This value is recomputed whenever the rule is modified.
condition: Option<Vec<Condition>>
The list of conditions that make up this rule (implicit AND between them).
account_id: Option<String>
GTM Account ID.