Struct google_tagmanager1::SetupTag
[−]
[src]
pub struct SetupTag {
pub stop_on_setup_failure: Option<bool>,
pub tag_name: Option<String>,
}There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
stop_on_setup_failure: Option<bool>
If true, fire the main tag if and only if the setup tag fires successfully. If false, fire the main tag regardless of setup tag firing status.
tag_name: Option<String>
The name of the setup tag.