Struct google_tagmanager1::api::ContainerVersion [−][src]
Represents a Google Tag Manager Container Version.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- containers versions get accounts (response)
- containers versions restore accounts (response)
- containers versions undelete accounts (response)
- containers versions update accounts (request|response)
Fields
account_id: Option<String>GTM Account ID.
container: Option<Container>The container that this version was taken from.
container_id: Option<String>GTM Container ID.
container_version_id: Option<String>The Container Version ID uniquely identifies the GTM Container Version.
deleted: Option<bool>A value of true indicates this container version has been deleted.
fingerprint: Option<String>The fingerprint of the GTM Container Version as computed at storage time. This value is recomputed whenever the container version is modified.
folder: Option<Vec<Folder>>The folders in the container that this version was taken from.
macro_: Option<Vec<Macro>>The macros in the container that this version was taken from.
name: Option<String>Container version display name. @mutable tagmanager.accounts.containers.versions.update
notes: Option<String>User notes on how to apply this container version in the container. @mutable tagmanager.accounts.containers.versions.update
rule: Option<Vec<Rule>>The rules in the container that this version was taken from.
tag: Option<Vec<Tag>>The tags in the container that this version was taken from.
trigger: Option<Vec<Trigger>>The triggers in the container that this version was taken from.
variable: Option<Vec<Variable>>The variables in the container that this version was taken from.