Struct google_tagmanager1::api::Rule [−][src]
Represents a Google Tag Manager Rule.
This type is not used in any activity, and only used as part of another schema.
Fields
account_id: Option<String>GTM Account ID.
condition: Option<Vec<Condition>>The list of conditions that make up this rule (implicit AND between them). @mutable tagmanager.accounts.containers.rules.create @mutable tagmanager.accounts.containers.rules.update
container_id: Option<String>GTM Container ID.
fingerprint: Option<String>The fingerprint of the GTM Rule as computed at storage time. This value is recomputed whenever the rule is modified.
name: Option<String>Rule display name. @mutable tagmanager.accounts.containers.rules.create @mutable tagmanager.accounts.containers.rules.update
notes: Option<String>User notes on how to apply this rule in the container. @mutable tagmanager.accounts.containers.rules.create @mutable tagmanager.accounts.containers.rules.update
rule_id: Option<String>The Rule ID uniquely identifies the GTM Rule.