Struct google_tagmanager1::ListContainerVersionsResponse
[−]
[src]
pub struct ListContainerVersionsResponse {
pub container_version_header: Option<Vec<ContainerVersionHeader>>,
pub container_version: Option<Vec<ContainerVersion>>,
}List container versions response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- containers versions list accounts (response)
Fields
container_version_header: Option<Vec<ContainerVersionHeader>>
All container version headers of a GTM Container.
container_version: Option<Vec<ContainerVersion>>
All versions of a GTM Container.